********************************************************************************************
* This file uses the dataset created by the "MungingForTables4and5_share.R" script 
* to run the models for the results listed in Tables 4 and 5.
*********************************************************************************************

***************************
*Import and recode the data
***************************

*Import the data and force numeric values to be stored as floating points"
import delimited "F:\AnalysisData\widedata.csv"
destring, replace force float

*Remove duplicates*
duplicates tag id, gen(isdup)
keep if isdup == 0
drop isdup

*Melt repeated measures data from wide to long format*
reshape long bp ssup sc, i(id) j(age)

*Replace assessment phases with age in years and center around age 15*
generate agec = age-4
recode agec -3=4 -2=7 -1=11 0=15

***************************
*Center social support and self-control variables around grand mean and person mean
***************************

egen pmnssup = mean(ssup), by(id)
egen grandssup = mean(ssup)
generate grmncssup = pmnssup - grandssup
generate pmcssup = ssup - pmnssup

egen pmnsc = mean(sc), by(id)
egen grandsc = mean(sc)
generate grmncsc = pmnsc - grandsc
generate pmcsc = sc - pmnsc

***************************
*Run the models and store the estimates for nested comparisons and likelihood ratio tests
***************************

*Random intercept
xtmixed bp agec || id:, cov(uns) mle var
estimates store ri

*Random intercept and slope (Model 1 in Table 4)
xtmixed bp agec || id: agec, cov(uns) mle var
estimates store rc

*Random intercept and slope with delay of gratification (Model 2 in Table 4, Column 1 in Table S4)
xtmixed bp c.agec##c.dog || id: agec, cov(uns) mle var
estimates store model1

*Random intercept and slope with social support (Column 2 in Table S4)
xtmixed bp c.agec##c.grmncssup || id: agec, cov(uns) mle var
estimates store model2

*Random intercept and slope with self-control (Column 3 in Table S4)
xtmixed bp c.agec##c.grmncsc || id: agec, cov(uns) mle var
estimates store model3

*Random intercept and slope with delay of gratification and social support (Model 4 in Table 4, Column 4 in Table S4)
xtmixed bp agec dog grmncssup || id: agec, cov(uns) mle var
estimates store model4

*Random intercept and slope with delay of gratification and self-control (Model 3 in Table 4, Column 5 in Table S4)
xtmixed bp agec dog grmncsc || id: agec, cov(uns) mle var
estimates store model5

*Random intercept and slope with delay of gratification, social support, and self-control (Column 6 in Table S4)
xtmixed bp agec dog grmncssup grmncsc || id: agec, cov(uns) mle var
estimates store model6

